@@ -39,7 +39,7 @@ struct aclk_node_info {
     const char *custom_info;
     const char *machine_guid;
 
-    DICTIONARY *host_labels_ptr;
+    RRDLABELS *host_labels_ptr;
     struct machine_learning_info ml_info;
 };
 
