@@ -3,6 +3,6 @@
 #ifndef NETDATA_CLI_H
 #define NETDATA_CLI_H 1
 
-#include "../daemon/common.h"
+#include "daemon/common.h"
 
 #endif //NETDATA_CLI_H
