@@ -266,65 +266,76 @@
 
 // IP STACK
 
-#define NETDATA_CHART_PRIO_IP_ERRORS                  4100
-#define NETDATA_CHART_PRIO_IP_TCP_CONNABORTS          4210
-#define NETDATA_CHART_PRIO_IP_TCP_SYN_QUEUE           4215
-#define NETDATA_CHART_PRIO_IP_TCP_ACCEPT_QUEUE        4216
-#define NETDATA_CHART_PRIO_IP_TCP_REORDERS            4220
-#define NETDATA_CHART_PRIO_IP_TCP_OFO                 4250
-#define NETDATA_CHART_PRIO_IP_TCP_SYNCOOKIES          4260
-#define NETDATA_CHART_PRIO_IP_TCP_MEM                 4290
-#define NETDATA_CHART_PRIO_IP_BCAST                   4500
-#define NETDATA_CHART_PRIO_IP_BCAST_PACKETS           4510
-#define NETDATA_CHART_PRIO_IP_MCAST                   4600
-#define NETDATA_CHART_PRIO_IP_MCAST_PACKETS           4610
-#define NETDATA_CHART_PRIO_IP_ECN                     4700
+#define NETDATA_CHART_PRIO_IP_TCP_PACKETS             4200
+#define NETDATA_CHART_PRIO_IP_TCP_ERRORS              4210
+#define NETDATA_CHART_PRIO_IP_TCP_ESTABLISHED_CONNS   4220
+#define NETDATA_CHART_PRIO_IP_TCP_OPENS               4220
+#define NETDATA_CHART_PRIO_IP_TCP_HANDSHAKE           4230
+#define NETDATA_CHART_PRIO_IP_TCP_CONNABORTS          4240
+#define NETDATA_CHART_PRIO_IP_TCP_SYN_QUEUE           4250
+#define NETDATA_CHART_PRIO_IP_TCP_ACCEPT_QUEUE        4260
+#define NETDATA_CHART_PRIO_IP_TCP_REORDERS            4270
+#define NETDATA_CHART_PRIO_IP_TCP_OFO                 4280
+#define NETDATA_CHART_PRIO_IP_TCP_SYNCOOKIES          4290
+#define NETDATA_CHART_PRIO_IP_TCP_MEM_PRESSURE        4300
+#define NETDATA_CHART_PRIO_IP_SOCKETS                 4310
 
 // IPv4
 
-#define NETDATA_CHART_PRIO_IPV4_SOCKETS               5100
-#define NETDATA_CHART_PRIO_IPV4_PACKETS               5130
-#define NETDATA_CHART_PRIO_IPV4_ERRORS                5150
-#define NETDATA_CHART_PRIO_IPV4_ICMP                  5170
-#define NETDATA_CHART_PRIO_IPV4_TCP                   5200
-#define NETDATA_CHART_PRIO_IPV4_TCP_SOCKETS           5201
-#define NETDATA_CHART_PRIO_IPV4_TCP_MEM               5290
-#define NETDATA_CHART_PRIO_IPV4_UDP                   5300
-#define NETDATA_CHART_PRIO_IPV4_UDP_MEM               5390
-#define NETDATA_CHART_PRIO_IPV4_UDPLITE               5400
+#define NETDATA_CHART_PRIO_IPV4_PACKETS               5000
+#define NETDATA_CHART_PRIO_IPV4_ERRORS                5050
+#define NETDATA_CHART_PRIO_IPV4_BCAST                 5100
+#define NETDATA_CHART_PRIO_IPV4_BCAST_PACKETS         5105
+#define NETDATA_CHART_PRIO_IPV4_MCAST                 5150
+#define NETDATA_CHART_PRIO_IPV4_MCAST_PACKETS         5155
+#define NETDATA_CHART_PRIO_IPV4_TCP_SOCKETS           5180
+#define NETDATA_CHART_PRIO_IPV4_TCP_SOCKETS_MEM       5185
+#define NETDATA_CHART_PRIO_IPV4_ICMP_PACKETS          5200
+#define NETDATA_CHART_PRIO_IPV4_ICMP_MESSAGES         5205
+#define NETDATA_CHART_PRIO_IPV4_ICMP_ERRORS           5210
+#define NETDATA_CHART_PRIO_IPV4_UDP_PACKETS           5250
+#define NETDATA_CHART_PRIO_IPV4_UDP_ERRORS            5255
+#define NETDATA_CHART_PRIO_IPV4_UDP_SOCKETS           5260
+#define NETDATA_CHART_PRIO_IPV4_UDP_SOCKETS_MEM       5265
+#define NETDATA_CHART_PRIO_IPV4_UDPLITE_PACKETS       5300
+#define NETDATA_CHART_PRIO_IPV4_UDPLITE_ERRORS        5305
+#define NETDATA_CHART_PRIO_IPV4_UDPLITE_SOCKETS       5310
+#define NETDATA_CHART_PRIO_IPV4_ECN                   5350
+#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS_IN          5400
+#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS_OUT         5405
+#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS_SOCKETS     5410
+#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS_SOCKETS_MEM 5415
 #define NETDATA_CHART_PRIO_IPV4_RAW                   5450
-#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS             5460
-#define NETDATA_CHART_PRIO_IPV4_FRAGMENTS_MEM         5470
 
 // IPv6
-
-#define NETDATA_CHART_PRIO_IPV6_PACKETS               6200
-#define NETDATA_CHART_PRIO_IPV6_ECT                   6210
-#define NETDATA_CHART_PRIO_IPV6_ERRORS                6300
-#define NETDATA_CHART_PRIO_IPV6_FRAGMENTS             6400
-#define NETDATA_CHART_PRIO_IPV6_FRAGSOUT              6401
-#define NETDATA_CHART_PRIO_IPV6_FRAGSIN               6402
-#define NETDATA_CHART_PRIO_IPV6_TCP                   6500
-#define NETDATA_CHART_PRIO_IPV6_UDP                   6600
-#define NETDATA_CHART_PRIO_IPV6_UDP_PACKETS           6601
-#define NETDATA_CHART_PRIO_IPV6_UDP_ERRORS            6610
-#define NETDATA_CHART_PRIO_IPV6_UDPLITE               6700
-#define NETDATA_CHART_PRIO_IPV6_UDPLITE_PACKETS       6701
-#define NETDATA_CHART_PRIO_IPV6_UDPLITE_ERRORS        6710
-#define NETDATA_CHART_PRIO_IPV6_RAW                   6800
-#define NETDATA_CHART_PRIO_IPV6_BCAST                 6840
-#define NETDATA_CHART_PRIO_IPV6_MCAST                 6850
-#define NETDATA_CHART_PRIO_IPV6_MCAST_PACKETS         6851
-#define NETDATA_CHART_PRIO_IPV6_ICMP                  6900
-#define NETDATA_CHART_PRIO_IPV6_ICMP_REDIR            6910
-#define NETDATA_CHART_PRIO_IPV6_ICMP_ERRORS           6920
-#define NETDATA_CHART_PRIO_IPV6_ICMP_ECHOS            6930
-#define NETDATA_CHART_PRIO_IPV6_ICMP_GROUPMEMB        6940
-#define NETDATA_CHART_PRIO_IPV6_ICMP_ROUTER           6950
-#define NETDATA_CHART_PRIO_IPV6_ICMP_NEIGHBOR         6960
-#define NETDATA_CHART_PRIO_IPV6_ICMP_LDV2             6970
-#define NETDATA_CHART_PRIO_IPV6_ICMP_TYPES            6980
-
+#define NETDATA_CHART_PRIO_IPV6_PACKETS               6000
+#define NETDATA_CHART_PRIO_IPV6_ERRORS                6005
+#define NETDATA_CHART_PRIO_IPV6_BCAST                 6050
+#define NETDATA_CHART_PRIO_IPV6_MCAST                 6100
+#define NETDATA_CHART_PRIO_IPV6_MCAST_PACKETS         6105
+#define NETDATA_CHART_PRIO_IPV6_TCP_SOCKETS           6140
+#define NETDATA_CHART_PRIO_IPV6_ICMP                  6150
+#define NETDATA_CHART_PRIO_IPV6_ICMP_REDIR            6155
+#define NETDATA_CHART_PRIO_IPV6_ICMP_ERRORS           6160
+#define NETDATA_CHART_PRIO_IPV6_ICMP_ECHOS            6165
+#define NETDATA_CHART_PRIO_IPV6_ICMP_GROUPMEMB        6170
+#define NETDATA_CHART_PRIO_IPV6_ICMP_ROUTER           6180
+#define NETDATA_CHART_PRIO_IPV6_ICMP_NEIGHBOR         6185
+#define NETDATA_CHART_PRIO_IPV6_ICMP_LDV2             6190
+#define NETDATA_CHART_PRIO_IPV6_ICMP_TYPES            6195
+#define NETDATA_CHART_PRIO_IPV6_UDP                   6200
+#define NETDATA_CHART_PRIO_IPV6_UDP_PACKETS           6205
+#define NETDATA_CHART_PRIO_IPV6_UDP_ERRORS            6210
+#define NETDATA_CHART_PRIO_IPV6_UDP_SOCKETS           6215
+#define NETDATA_CHART_PRIO_IPV6_UDPLITE               6250
+#define NETDATA_CHART_PRIO_IPV6_UDPLITE_PACKETS       6255
+#define NETDATA_CHART_PRIO_IPV6_UDPLITE_ERRORS        6260
+#define NETDATA_CHART_PRIO_IPV6_UDPLITE_SOCKETS       6265
+#define NETDATA_CHART_PRIO_IPV6_ECT                   6300
+#define NETDATA_CHART_PRIO_IPV6_FRAGSIN               6350
+#define NETDATA_CHART_PRIO_IPV6_FRAGSOUT              6355
+#define NETDATA_CHART_PRIO_IPV6_FRAGMENTS_SOCKETS     6360
+#define NETDATA_CHART_PRIO_IPV6_RAW_SOCKETS           6400
 
 // Network interfaces
 
@@ -403,7 +414,8 @@
 // [ml] charts
 #define ML_CHART_PRIO_DIMENSIONS                      39181
 #define ML_CHART_PRIO_ANOMALY_RATE                    39182
-#define ML_CHART_PRIO_DETECTOR_EVENTS                 39183
+#define ML_CHART_PRIO_TYPE_ANOMALY_RATE               39183
+#define ML_CHART_PRIO_DETECTOR_EVENTS                 39184
 
 // [netdata.ml] charts
 #define NETDATA_ML_CHART_RUNNING                      890001
