@@ -16,6 +16,21 @@ export LC_ALL=C
 
 PROGRAM_NAME="$(basename "${0}")"
 
+LOG_LEVEL_ERR=1
+LOG_LEVEL_WARN=2
+LOG_LEVEL_INFO=3
+LOG_LEVEL="$LOG_LEVEL_INFO"
+
+set_log_severity_level() {
+  case ${NETDATA_LOG_SEVERITY_LEVEL,,} in
+    "info") LOG_LEVEL="$LOG_LEVEL_INFO";;
+    "warn" | "warning") LOG_LEVEL="$LOG_LEVEL_WARN";;
+    "err" | "error") LOG_LEVEL="$LOG_LEVEL_ERR";;
+  esac
+}
+
+set_log_severity_level
+
 logdate() {
   date "+%Y-%m-%d %H:%M:%S"
 }
@@ -28,18 +43,21 @@ log() {
 
 }
 
+info() {
+  [[ -n "$LOG_LEVEL" && "$LOG_LEVEL_INFO" -gt "$LOG_LEVEL" ]] && return
+  log INFO "${@}"
+}
+
 warning() {
+  [[ -n "$LOG_LEVEL" && "$LOG_LEVEL_WARN" -gt "$LOG_LEVEL" ]] && return
   log WARNING "${@}"
 }
 
 error() {
+  [[ -n "$LOG_LEVEL" && "$LOG_LEVEL_ERR" -gt "$LOG_LEVEL" ]] && return
   log ERROR "${@}"
 }
 
-info() {
-  log INFO "${@}"
-}
-
 fatal() {
   log FATAL "${@}"
   exit 1
@@ -47,11 +65,14 @@ fatal() {
 
 function parse_docker_like_inspect_output() {
   local output="${1}"
-  eval "$(grep -E "^(NOMAD_NAMESPACE|NOMAD_JOB_NAME|NOMAD_TASK_NAME|NOMAD_SHORT_ALLOC_ID|CONT_NAME)=" <<<"$output")"
+  eval "$(grep -E "^(NOMAD_NAMESPACE|NOMAD_JOB_NAME|NOMAD_TASK_NAME|NOMAD_SHORT_ALLOC_ID|CONT_NAME|IMAGE_NAME)=" <<<"$output")"
   if [ -n "$NOMAD_NAMESPACE" ] && [ -n "$NOMAD_JOB_NAME" ] && [ -n "$NOMAD_TASK_NAME" ] && [ -n "$NOMAD_SHORT_ALLOC_ID" ]; then
-    echo "${NOMAD_NAMESPACE}-${NOMAD_JOB_NAME}-${NOMAD_TASK_NAME}-${NOMAD_SHORT_ALLOC_ID}"
+    NAME="${NOMAD_NAMESPACE}-${NOMAD_JOB_NAME}-${NOMAD_TASK_NAME}-${NOMAD_SHORT_ALLOC_ID}"
   else
-    echo "${CONT_NAME}" | sed 's|^/||'
+    NAME=$(echo "${CONT_NAME}" | sed 's|^/||')
+  fi
+  if [ -n "${IMAGE_NAME}" ]; then
+    LABELS="image=\"${IMAGE_NAME}\""
   fi
 }
 
@@ -59,9 +80,9 @@ function docker_like_get_name_command() {
   local command="${1}"
   local id="${2}"
   info "Running command: ${command} inspect --format='{{range .Config.Env}}{{println .}}{{end}}CONT_NAME={{ .Name}}' \"${id}\""
-  if OUTPUT="$(${command} inspect --format='{{range .Config.Env}}{{println .}}{{end}}CONT_NAME={{ .Name}}' "${id}")" &&
+  if OUTPUT="$(${command} inspect --format='{{range .Config.Env}}{{println .}}{{end}}CONT_NAME={{ .Name}}{{println}}IMAGE_NAME={{ .Config.Image}}' "${id}")" &&
     [ -n "$OUTPUT" ]; then
-      NAME="$(parse_docker_like_inspect_output "$OUTPUT")"
+      parse_docker_like_inspect_output "$OUTPUT"
   fi
   return 0
 }
@@ -85,8 +106,8 @@ function docker_like_get_name_api() {
     info "Running API command: curl \"${host}${path}\""
     JSON=$(curl -sS "${host}${path}")
   fi
-  if OUTPUT=$(echo "${JSON}" | jq -r '.Config.Env[],"CONT_NAME=\(.Name)"') && [ -n "$OUTPUT" ]; then
-    NAME="$(parse_docker_like_inspect_output "$OUTPUT")"
+  if OUTPUT=$(echo "${JSON}" | jq -r '.Config.Env[],"CONT_NAME=\(.Name)","IMAGE_NAME=\(.Config.Image)"') && [ -n "$OUTPUT" ]; then
+    parse_docker_like_inspect_output "$OUTPUT"
   fi
   return 0
 }
@@ -129,6 +150,22 @@ function add_lbl_prefix() {
   echo "${new_labels:0:-1}" # trim last ','
 }
 
+function remove_lbl() {
+  local orig_labels lbl_name
+  orig_labels="${1}"
+  lbl_name="${2}"
+
+  IFS=, read -ra labels <<< "$orig_labels"
+
+  local new_labels
+  for l in "${labels[@]}"; do
+    IFS="=" read -r lname lval <<< "$l"
+    [ "$lbl_name" != "$lname" ] && new_labels+="${l},"
+  done
+
+  echo "${new_labels:0:-1}" # trim last ','
+}
+
 function k8s_is_pause_container() {
   local cgroup_path="${1}"
 
@@ -303,8 +340,14 @@ function k8s_get_kubepod_name() {
         fi
       fi
 
-      url="https://$host/api/v1/pods"
-      [ -n "$MY_NODE_NAME" ] && url+="?fieldSelector=spec.nodeName==$MY_NODE_NAME"
+      local url
+      if [ -n "${USE_KUBELET_FOR_PODS_METADATA}" ]; then
+        url="${KUBELET_URL:-https://localhost:10250}/pods"
+      else
+        url="https://$host/api/v1/pods"
+        [ -n "$MY_NODE_NAME" ] && url+="?fieldSelector=spec.nodeName==$MY_NODE_NAME"
+      fi
+
       # FIX: check HTTP response code
       if ! pods=$(curl --fail -sSk -H "$header" "$url" 2>&1); then
         warning "${fn}: error on curl '${url}': ${pods}."
@@ -376,6 +419,8 @@ function k8s_get_kubepod_name() {
       name+="_$(get_lbl_val "$labels" namespace)"
       name+="_$(get_lbl_val "$labels" pod_name)"
       name+="_$(get_lbl_val "$labels" container_name)"
+      labels=$(remove_lbl "$labels" "container_id")
+      labels=$(remove_lbl "$labels" "pod_uid")
       labels=$(add_lbl_prefix "$labels" "k8s_")
       name+=" $labels"
     else
@@ -391,6 +436,7 @@ function k8s_get_kubepod_name() {
       name="pod"
       name+="_$(get_lbl_val "$labels" namespace)"
       name+="_$(get_lbl_val "$labels" pod_name)"
+      labels=$(remove_lbl "$labels" "pod_uid")
       labels=$(add_lbl_prefix "$labels" "k8s_")
       name+=" $labels"
     else
@@ -401,6 +447,10 @@ function k8s_get_kubepod_name() {
   # jq filter nonexistent field and nonexistent label value is 'null'
   if [[ $name =~ _null(_|$) ]]; then
     warning "${fn}: invalid name: $name (cgroup '$id')"
+    if [ -n "${USE_KUBELET_FOR_PODS_METADATA}" ]; then
+      # local data is cached and may not contain the correct id
+      return 2
+    fi
     return 1
   fi
 
@@ -413,20 +463,25 @@ function k8s_get_name() {
   local fn="${FUNCNAME[0]}"
   local cgroup_path="${1}"
   local id="${2}"
+  local kubepod_name=""
 
-  NAME=$(k8s_get_kubepod_name "$cgroup_path" "$id")
+  kubepod_name=$(k8s_get_kubepod_name "$cgroup_path" "$id")
 
   case "$?" in
   0)
-    NAME="k8s_${NAME}"
+    kubepod_name="k8s_${kubepod_name}"
 
     local name labels
-    name=${NAME%% *}
-    labels=${NAME#* }
+    name=${kubepod_name%% *}
+    labels=${kubepod_name#* }
+
     if [ "$name" != "$labels" ]; then
       info "${fn}: cgroup '${id}' has chart name '${name}', labels '${labels}"
+      NAME="$name"
+      LABELS="$labels"
     else
       info "${fn}: cgroup '${id}' has chart name '${NAME}'"
+      NAME="$name"
     fi
     EXIT_CODE=$EXIT_SUCCESS
     ;;
@@ -512,6 +567,7 @@ EXIT_RETRY=2
 EXIT_DISABLE=3
 EXIT_CODE=$EXIT_SUCCESS
 NAME=
+LABELS=
 
 # -----------------------------------------------------------------------------
 
@@ -591,7 +647,13 @@ if [ -z "${NAME}" ]; then
   [ ${#NAME} -gt 100 ] && NAME="${NAME:0:100}"
 fi
 
-info "cgroup '${CGROUP}' is called '${NAME}'"
-echo "${NAME}"
+NAME="${NAME// /_}"
+
+info "cgroup '${CGROUP}' is called '${NAME}', labels '${LABELS}'"
+if [ -n "$LABELS" ]; then
+  echo "${NAME} ${LABELS}"
+else
+  echo "${NAME}"
+fi
 
 exit ${EXIT_CODE}
