@@ -3,15 +3,18 @@
 #ifndef NETDATA_EBPF_FILESYSTEM_H
 #define NETDATA_EBPF_FILESYSTEM_H 1
 
-// Module name
+// Module name & description
 #define NETDATA_EBPF_MODULE_NAME_FILESYSTEM "filesystem"
+#define NETDATA_EBPF_FS_MODULE_DESC "Monitor filesystem latency for: btrfs, ext4, nfs, xfs and zfs."
 
 #include "ebpf.h"
+#ifdef LIBBPF_MAJOR_VERSION
+#include "includes/filesystem.skel.h"
+#endif
 
 #define NETDATA_FS_MAX_DIST_NAME 64UL
 
 #define NETDATA_FILESYSTEM_CONFIG_NAME "filesystem"
-#define NETDATA_FILESYSTEM_READ_SLEEP_MS 600000ULL
 
 // Process configuration name
 #define NETDATA_FILESYSTEM_CONFIG_FILE "filesystem.conf"
@@ -43,6 +46,16 @@ enum netdata_filesystem_table {
     NETDATA_ADDR_FS_TABLE
 };
 
+enum netdata_filesystem_localfs_idx {
+    NETDATA_FS_LOCALFS_EXT4,
+    NETDATA_FS_LOCALFS_XFS,
+    NETDATA_FS_LOCALFS_NFS,
+    NETDATA_FS_LOCALFS_ZFS,
+    NETDATA_FS_LOCALFS_BTRFS,
+
+    NETDATA_FS_LOCALFS_END,
+};
+
 void *ebpf_filesystem_thread(void *ptr);
 extern struct config fs_config;
 
