@@ -3,6 +3,9 @@
 #ifndef NETDATA_EBPF_OOMKILL_H
 #define NETDATA_EBPF_OOMKILL_H 1
 
+// Module description
+#define NETDATA_EBPF_OOMKILL_MODULE_DESC "Show OOM kills for all applications recognized via the apps.plugin."
+
 /*****************************************************************
  *  copied from kernel-collectors repo, with modifications needed
  *  for inclusion here.
@@ -17,7 +20,6 @@ typedef uint8_t oomkill_ebpf_val_t;
  *****************************************************************/
 
 #define NETDATA_EBPF_MODULE_NAME_OOMKILL "oomkill"
-#define NETDATA_OOMKILL_SLEEP_MS 650000ULL
 #define NETDATA_OOMKILL_CONFIG_FILE "oomkill.conf"
 
 #define NETDATA_OOMKILL_CHART "oomkills"
