@@ -52,7 +52,8 @@ enum netdata_ebpf_stats_order {
     NETDATA_EBPF_ORDER_STAT_HASH_GLOBAL_TABLE_TOTAL,
     NETDATA_EBPF_ORDER_STAT_HASH_PID_TABLE_ADDED,
     NETDATA_EBPF_ORDER_STAT_HASH_PID_TABLE_REMOVED,
-    NETATA_EBPF_ORDER_STAT_ARAL_BEGIN
+    NETATA_EBPF_ORDER_STAT_ARAL_BEGIN,
+    NETDATA_EBPF_ORDER_FUNCTION_PER_THREAD,
 };
 
 enum netdata_ebpf_load_mode_stats{
