@@ -54,7 +54,7 @@ static void mount_points_cleanup() {
     struct mount_point *m = mount_points_root, *last = NULL;
     while(m) {
         if (unlikely(!m->updated)) {
-            // info("Removing mount point '%s', linked after '%s'", m->name, last?last->name:"ROOT");
+            // collector_info("Removing mount point '%s', linked after '%s'", m->name, last?last->name:"ROOT");
 
             if (mount_points_last_used == m)
                 mount_points_last_used = last;
@@ -143,18 +143,16 @@ int do_getmntinfo(int update_every, usec_t dt) {
         do_inodes = config_get_boolean_ondemand(CONFIG_SECTION_GETMNTINFO, "inodes usage for all disks", CONFIG_BOOLEAN_AUTO);
 
         excluded_mountpoints = simple_pattern_create(
-                config_get(CONFIG_SECTION_GETMNTINFO, "exclude space metrics on paths",
-                           DEFAULT_EXCLUDED_PATHS)
-                , NULL
-                , SIMPLE_PATTERN_EXACT
-        );
+            config_get(CONFIG_SECTION_GETMNTINFO, "exclude space metrics on paths", DEFAULT_EXCLUDED_PATHS),
+            NULL,
+            SIMPLE_PATTERN_EXACT,
+            true);
 
         excluded_filesystems = simple_pattern_create(
-                config_get(CONFIG_SECTION_GETMNTINFO, "exclude space metrics on filesystems",
-                           DEFAULT_EXCLUDED_FILESYSTEMS)
-                , NULL
-                , SIMPLE_PATTERN_EXACT
-        );
+            config_get(CONFIG_SECTION_GETMNTINFO, "exclude space metrics on filesystems", DEFAULT_EXCLUDED_FILESYSTEMS),
+            NULL,
+            SIMPLE_PATTERN_EXACT,
+            true);
     }
 
     if (likely(do_space || do_inodes)) {
@@ -163,12 +161,12 @@ int do_getmntinfo(int update_every, usec_t dt) {
 
         // there is no mount info in sysctl MIBs
         if (unlikely(!(mntsize = getmntinfo(&mntbuf, MNT_NOWAIT)))) {
-            error("FREEBSD: getmntinfo() failed");
+            collector_error("FREEBSD: getmntinfo() failed");
             do_space = 0;
-            error("DISABLED: disk_space.* charts");
+            collector_error("DISABLED: disk_space.* charts");
             do_inodes = 0;
-            error("DISABLED: disk_inodes.* charts");
-            error("DISABLED: getmntinfo module");
+            collector_error("DISABLED: disk_inodes.* charts");
+            collector_error("DISABLED: getmntinfo module");
             return 1;
         } else {
             int i;
@@ -289,7 +287,7 @@ int do_getmntinfo(int update_every, usec_t dt) {
             }
         }
     } else {
-        error("DISABLED: getmntinfo module");
+        collector_error("DISABLED: getmntinfo module");
         return 1;
     }
 
