@@ -17,6 +17,11 @@
 static struct disk {
     char *disk;             // the name of the disk (sda, sdb, etc, after being looked up)
     char *device;           // the device of the disk (before being looked up)
+    char *disk_by_id;
+    char *model;
+    char *serial;
+//    bool rotational;
+//    bool removable;
     uint32_t hash;
     unsigned long major;
     unsigned long minor;
@@ -172,6 +177,8 @@ static char *path_to_sys_block_device = NULL;
 static char *path_to_sys_block_device_bcache = NULL;
 static char *path_to_sys_devices_virtual_block_device = NULL;
 static char *path_to_device_mapper = NULL;
+static char *path_to_dev_disk = NULL;
+static char *path_to_sys_block = NULL;
 static char *path_to_device_label = NULL;
 static char *path_to_device_id = NULL;
 static char *path_to_veritas_volume_groups = NULL;
@@ -214,7 +221,7 @@ static unsigned long long int bcache_read_number_with_units(const char *filename
             else if(*end == 'T')
                 return (unsigned long long int)(value * 1024.0 * 1024.0 * 1024.0 * 1024.0);
             else if(unknown_units_error > 0) {
-                error("bcache file '%s' provides value '%s' with unknown units '%s'", filename, buffer, end);
+                collector_error("bcache file '%s' provides value '%s' with unknown units '%s'", filename, buffer, end);
                 unknown_units_error--;
             }
         }
@@ -269,7 +276,7 @@ void bcache_read_priority_stats(struct disk *d, const char *family, int update_e
     for(l = 0; l < lines ;l++) {
         size_t words = procfile_linewords(ff, l);
         if(unlikely(words < 2)) {
-            if(unlikely(words)) error("Cannot read '%s' line %zu. Expected 2 params, read %zu.", d->bcache_filename_priority_stats, l, words);
+            if(unlikely(words)) collector_error("Cannot read '%s' line %zu. Expected 2 params, read %zu.", d->bcache_filename_priority_stats, l, words);
             continue;
         }
 
@@ -344,15 +351,15 @@ static inline int is_major_enabled(int major) {
 }
 
 static inline int get_disk_name_from_path(const char *path, char *result, size_t result_size, unsigned long major, unsigned long minor, char *disk, char *prefix, int depth) {
-    //info("DEVICE-MAPPER ('%s', %lu:%lu): examining directory '%s' (allowed depth %d).", disk, major, minor, path, depth);
+    //collector_info("DEVICE-MAPPER ('%s', %lu:%lu): examining directory '%s' (allowed depth %d).", disk, major, minor, path, depth);
 
     int found = 0, preferred = 0;
 
-    char *first_result = mallocz(result_size);
+    char *first_result = mallocz(result_size + 1);
 
     DIR *dir = opendir(path);
     if (!dir) {
-        error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot open directory '%s'.", disk, major, minor, path);
+        collector_error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot open directory '%s'.", disk, major, minor, path);
         goto failed;
     }
 
@@ -363,7 +370,7 @@ static inline int get_disk_name_from_path(const char *path, char *result, size_t
                 continue;
 
             if(depth <= 0) {
-                error("DEVICE-MAPPER ('%s', %lu:%lu): Depth limit reached for path '%s/%s'. Ignoring path.", disk, major, minor, path, de->d_name);
+                collector_error("DEVICE-MAPPER ('%s', %lu:%lu): Depth limit reached for path '%s/%s'. Ignoring path.", disk, major, minor, path, de->d_name);
                 break;
             }
             else {
@@ -393,7 +400,7 @@ static inline int get_disk_name_from_path(const char *path, char *result, size_t
                 snprintfz(filename, FILENAME_MAX, "%s/%s", path, de->d_name);
                 ssize_t len = readlink(filename, result, result_size - 1);
                 if(len <= 0) {
-                    error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot read link '%s'.", disk, major, minor, filename);
+                    collector_error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot read link '%s'.", disk, major, minor, filename);
                     continue;
                 }
 
@@ -409,21 +416,21 @@ static inline int get_disk_name_from_path(const char *path, char *result, size_t
 
             struct stat sb;
             if(stat(filename, &sb) == -1) {
-                error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot stat() file '%s'.", disk, major, minor, filename);
+                collector_error("DEVICE-MAPPER ('%s', %lu:%lu): Cannot stat() file '%s'.", disk, major, minor, filename);
                 continue;
             }
 
             if((sb.st_mode & S_IFMT) != S_IFBLK) {
-                //info("DEVICE-MAPPER ('%s', %lu:%lu): file '%s' is not a block device.", disk, major, minor, filename);
+                //collector_info("DEVICE-MAPPER ('%s', %lu:%lu): file '%s' is not a block device.", disk, major, minor, filename);
                 continue;
             }
 
             if(major(sb.st_rdev) != major || minor(sb.st_rdev) != minor || strcmp(basename(filename), disk)) {
-                //info("DEVICE-MAPPER ('%s', %lu:%lu): filename '%s' does not match %lu:%lu.", disk, major, minor, filename, (unsigned long)major(sb.st_rdev), (unsigned long)minor(sb.st_rdev));
+                //collector_info("DEVICE-MAPPER ('%s', %lu:%lu): filename '%s' does not match %lu:%lu.", disk, major, minor, filename, (unsigned long)major(sb.st_rdev), (unsigned long)minor(sb.st_rdev));
                 continue;
             }
 
-            //info("DEVICE-MAPPER ('%s', %lu:%lu): filename '%s' matches.", disk, major, minor, filename);
+            //collector_info("DEVICE-MAPPER ('%s', %lu:%lu): filename '%s' matches.", disk, major, minor, filename);
 
             snprintfz(result, result_size - 1, "%s%s%s", (prefix)?prefix:"", (prefix)?"_":"", de->d_name);
 
@@ -454,7 +461,7 @@ failed:
 }
 
 static inline char *get_disk_name(unsigned long major, unsigned long minor, char *disk) {
-    char result[FILENAME_MAX + 1] = "";
+    char result[FILENAME_MAX + 2] = "";
 
     if(!path_to_device_mapper || !*path_to_device_mapper || !get_disk_name_from_path(path_to_device_mapper, result, FILENAME_MAX + 1, major, minor, disk, NULL, 0))
         if(!path_to_device_label || !*path_to_device_label || !get_disk_name_from_path(path_to_device_label, result, FILENAME_MAX + 1, major, minor, disk, NULL, 0))
@@ -469,6 +476,109 @@ static inline char *get_disk_name(unsigned long major, unsigned long minor, char
     return strdup(result);
 }
 
+static inline bool ends_with(const char *str, const char *suffix) {
+    if (!str || !suffix)
+        return false;
+
+    size_t len_str = strlen(str);
+    size_t len_suffix = strlen(suffix);
+    if (len_suffix > len_str)
+        return false;
+
+    return strncmp(str + len_str - len_suffix, suffix, len_suffix) == 0;
+}
+
+static inline char *get_disk_by_id(char *device) {
+    char pathname[256 + 1];
+    snprintfz(pathname, 256, "%s/by-id", path_to_dev_disk);
+
+    struct dirent *entry;
+    DIR *dp = opendir(pathname);
+    if (dp == NULL) {
+        internal_error(true, "Cannot open '%s'", pathname);
+        return NULL;
+    }
+
+    while ((entry = readdir(dp))) {
+        // We ignore the '.' and '..' entries
+        if (strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0)
+            continue;
+
+        if(strncmp(entry->d_name, "md-uuid-", 8) == 0 ||
+                strncmp(entry->d_name, "dm-uuid-", 8) == 0 ||
+                strncmp(entry->d_name, "nvme-eui.", 9) == 0 ||
+                strncmp(entry->d_name, "wwn-", 4) == 0 ||
+                strncmp(entry->d_name, "lvm-pv-uuid-", 12) == 0)
+            continue;
+
+        char link_target[256 + 1];
+        char full_path[256 + 1];
+        snprintfz(full_path, 256, "%s/%s", pathname, entry->d_name);
+
+        ssize_t len = readlink(full_path, link_target, 256);
+        if (len == -1)
+            continue;
+
+        link_target[len] = '\0';
+
+        if (ends_with(link_target, device)) {
+            char *s = strdupz(entry->d_name);
+            closedir(dp);
+            return s;
+        }
+    }
+
+    closedir(dp);
+    return NULL;
+}
+
+static inline char *get_disk_model(char *device) {
+    char path[256 + 1];
+    char buffer[256 + 1];
+
+    snprintfz(path, 256, "%s/%s/device/model", path_to_sys_block, device);
+    if(read_file(path, buffer, 256) != 0) {
+        snprintfz(path, 256, "%s/%s/device/name", path_to_sys_block, device);
+        if(read_file(path, buffer, 256) != 0)
+            return NULL;
+    }
+
+    return strdupz(buffer);
+}
+
+static inline char *get_disk_serial(char *device) {
+    char path[256 + 1];
+    char buffer[256 + 1];
+
+    snprintfz(path, 256, "%s/%s/device/serial", path_to_sys_block, device);
+    if(read_file(path, buffer, 256) != 0)
+        return NULL;
+
+    return strdupz(buffer);
+}
+
+//static inline bool get_disk_rotational(char *device) {
+//    char path[256 + 1];
+//    char buffer[256 + 1];
+//
+//    snprintfz(path, 256, "%s/%s/queue/rotational", path_to_sys_block, device);
+//    if(read_file(path, buffer, 256) != 0)
+//        return false;
+//
+//    return buffer[0] == '1';
+//}
+//
+//static inline bool get_disk_removable(char *device) {
+//    char path[256 + 1];
+//    char buffer[256 + 1];
+//
+//    snprintfz(path, 256, "%s/%s/removable", path_to_sys_block, device);
+//    if(read_file(path, buffer, 256) != 0)
+//        return false;
+//
+//    return buffer[0] == '1';
+//}
+
 static void get_disk_config(struct disk *d) {
     int def_enable = global_enable_new_disks_detected_at_runtime;
 
@@ -594,6 +704,11 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
 
     d->disk = get_disk_name(major, minor, disk);
     d->device = strdupz(disk);
+    d->disk_by_id = get_disk_by_id(disk);
+    d->model = get_disk_model(disk);
+    d->serial = get_disk_serial(disk);
+//    d->rotational = get_disk_rotational(disk);
+//    d->removable = get_disk_removable(disk);
     d->hash = simple_hash(d->device);
     d->major = major;
     d->minor = minor;
@@ -615,8 +730,8 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
     // read device uuid if it is an LVM volume
     if (!strncmp(d->device, "dm-", 3)) {
         char uuid_filename[FILENAME_MAX + 1];
-        snprintfz(uuid_filename, FILENAME_MAX, path_to_sys_devices_virtual_block_device, disk);
-        strncat(uuid_filename, "/dm/uuid", FILENAME_MAX);
+        int size = snprintfz(uuid_filename, FILENAME_MAX, path_to_sys_devices_virtual_block_device, disk);
+        strncat(uuid_filename, "/dm/uuid", FILENAME_MAX - size);
 
         char device_uuid[RRD_ID_LENGTH_MAX + 1];
         if (!read_file(uuid_filename, device_uuid, RRD_ID_LENGTH_MAX) && !strncmp(device_uuid, "LVM-", 4)) {
@@ -672,7 +787,7 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
                     break;
                 }
                 if (unlikely(closedir(dirp) == -1))
-                    error("Unable to close dir %s", buffer);
+                    collector_error("Unable to close dir %s", buffer);
             }
         }
     }
@@ -721,15 +836,15 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
             if(likely(tmp)) {
                 d->sector_size = str2i(tmp);
                 if(unlikely(d->sector_size <= 0)) {
-                    error("Invalid sector size %d for device %s in %s. Assuming 512.", d->sector_size, d->device, buffer);
+                    collector_error("Invalid sector size %d for device %s in %s. Assuming 512.", d->sector_size, d->device, buffer);
                     d->sector_size = 512;
                 }
             }
-            else error("Cannot read data for sector size for device %s from %s. Assuming 512.", d->device, buffer);
+            else collector_error("Cannot read data for sector size for device %s from %s. Assuming 512.", d->device, buffer);
 
             fclose(fpss);
         }
-        else error("Cannot read sector size for device %s from %s. Assuming 512.", d->device, buffer);
+        else collector_error("Cannot read sector size for device %s from %s. Assuming 512.", d->device, buffer);
     }
     */
 
@@ -748,103 +863,103 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_cache_congested = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/readahead", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_readaheads = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/cache/cache0/priority_stats", buffer); // only one cache is supported by bcache
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_priority_stats = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/cache/internal/cache_read_races", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_cache_read_races = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/cache/cache0/io_errors", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_cache_io_errors = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/dirty_data", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_dirty_data = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/writeback_rate", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_writeback_rate = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/cache/cache_available_percent", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_cache_available_percent = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_hits", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_hits = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_five_minute/cache_hit_ratio", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_five_minute_cache_hit_ratio = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_hour/cache_hit_ratio", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_hour_cache_hit_ratio = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_day/cache_hit_ratio", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_day_cache_hit_ratio = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_hit_ratio", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_hit_ratio = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_misses", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_misses = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_bypass_hits", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_bypass_hits = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_bypass_misses", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_bypass_misses = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
 
         snprintfz(buffer2, FILENAME_MAX, "%s/stats_total/cache_miss_collisions", buffer);
         if(access(buffer2, R_OK) == 0)
             d->bcache_filename_stats_total_cache_miss_collisions = strdupz(buffer2);
         else
-            error("bcache file '%s' cannot be read.", buffer2);
+            collector_error("bcache file '%s' cannot be read.", buffer2);
     }
 
     get_disk_config(d);
@@ -854,6 +969,11 @@ static struct disk *get_disk(unsigned long major, unsigned long minor, char *dis
 static void add_labels_to_disk(struct disk *d, RRDSET *st) {
     rrdlabels_add(st->rrdlabels, "device", d->disk, RRDLABEL_SRC_AUTO);
     rrdlabels_add(st->rrdlabels, "mount_point", d->mount_point, RRDLABEL_SRC_AUTO);
+    rrdlabels_add(st->rrdlabels, "id", d->disk_by_id, RRDLABEL_SRC_AUTO);
+    rrdlabels_add(st->rrdlabels, "model", d->model, RRDLABEL_SRC_AUTO);
+    rrdlabels_add(st->rrdlabels, "serial", d->serial, RRDLABEL_SRC_AUTO);
+//    rrdlabels_add(st->rrdlabels, "rotational", d->rotational ? "true" : "false", RRDLABEL_SRC_AUTO);
+//    rrdlabels_add(st->rrdlabels, "removable", d->removable ? "true" : "false", RRDLABEL_SRC_AUTO);
 
     switch (d->type) {
         default:
@@ -922,6 +1042,12 @@ int do_proc_diskstats(int update_every, usec_t dt) {
         snprintfz(buffer, FILENAME_MAX, "%s/dev/mapper", netdata_configured_host_prefix);
         path_to_device_mapper = config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "path to device mapper", buffer);
 
+        snprintfz(buffer, FILENAME_MAX, "%s/dev/disk", netdata_configured_host_prefix);
+        path_to_dev_disk = config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "path to /dev/disk", buffer);
+
+        snprintfz(buffer, FILENAME_MAX, "%s/sys/block", netdata_configured_host_prefix);
+        path_to_sys_block = config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "path to /sys/block", buffer);
+
         snprintfz(buffer, FILENAME_MAX, "%s/dev/disk/by-label", netdata_configured_host_prefix);
         path_to_device_label = config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "path to /dev/disk/by-label", buffer);
 
@@ -934,16 +1060,12 @@ int do_proc_diskstats(int update_every, usec_t dt) {
         name_disks_by_id = config_get_boolean(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "name disks by id", name_disks_by_id);
 
         preferred_ids = simple_pattern_create(
-                config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "preferred disk ids", DEFAULT_PREFERRED_IDS)
-                , NULL
-                , SIMPLE_PATTERN_EXACT
-        );
+                config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "preferred disk ids", DEFAULT_PREFERRED_IDS), NULL,
+                SIMPLE_PATTERN_EXACT, true);
 
         excluded_disks = simple_pattern_create(
-                config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "exclude disks", DEFAULT_EXCLUDED_DISKS)
-                , NULL
-                , SIMPLE_PATTERN_EXACT
-        );
+                config_get(CONFIG_SECTION_PLUGIN_PROC_DISKSTATS, "exclude disks", DEFAULT_EXCLUDED_DISKS), NULL,
+                SIMPLE_PATTERN_EXACT, true);
     }
 
     // --------------------------------------------------------------------------
@@ -993,35 +1115,35 @@ int do_proc_diskstats(int update_every, usec_t dt) {
 
         // # of reads completed # of writes completed
         // This is the total number of reads or writes completed successfully.
-        reads           = str2ull(procfile_lineword(ff, l, 3));  // rd_ios
-        writes          = str2ull(procfile_lineword(ff, l, 7));  // wr_ios
+        reads           = str2ull(procfile_lineword(ff, l, 3), NULL);  // rd_ios
+        writes          = str2ull(procfile_lineword(ff, l, 7), NULL);  // wr_ios
 
         // # of reads merged # of writes merged
         // Reads and writes which are adjacent to each other may be merged for
         // efficiency.  Thus two 4K reads may become one 8K read before it is
         // ultimately handed to the disk, and so it will be counted (and queued)
-        mreads          = str2ull(procfile_lineword(ff, l, 4));  // rd_merges_or_rd_sec
-        mwrites         = str2ull(procfile_lineword(ff, l, 8));  // wr_merges
+        mreads          = str2ull(procfile_lineword(ff, l, 4), NULL);  // rd_merges_or_rd_sec
+        mwrites         = str2ull(procfile_lineword(ff, l, 8), NULL);  // wr_merges
 
         // # of sectors read # of sectors written
         // This is the total number of sectors read or written successfully.
-        readsectors     = str2ull(procfile_lineword(ff, l, 5));  // rd_sec_or_wr_ios
-        writesectors    = str2ull(procfile_lineword(ff, l, 9));  // wr_sec
+        readsectors     = str2ull(procfile_lineword(ff, l, 5), NULL);  // rd_sec_or_wr_ios
+        writesectors    = str2ull(procfile_lineword(ff, l, 9), NULL);  // wr_sec
 
         // # of milliseconds spent reading # of milliseconds spent writing
         // This is the total number of milliseconds spent by all reads or writes (as
         // measured from __make_request() to end_that_request_last()).
-        readms          = str2ull(procfile_lineword(ff, l, 6));  // rd_ticks_or_wr_sec
-        writems         = str2ull(procfile_lineword(ff, l, 10)); // wr_ticks
+        readms          = str2ull(procfile_lineword(ff, l, 6), NULL);  // rd_ticks_or_wr_sec
+        writems         = str2ull(procfile_lineword(ff, l, 10), NULL); // wr_ticks
 
         // # of I/Os currently in progress
         // The only field that should go to zero. Incremented as requests are
         // given to appropriate struct request_queue and decremented as they finish.
-        queued_ios      = str2ull(procfile_lineword(ff, l, 11)); // ios_pgr
+        queued_ios      = str2ull(procfile_lineword(ff, l, 11), NULL); // ios_pgr
 
         // # of milliseconds spent doing I/Os
         // This field increases so long as field queued_ios is nonzero.
-        busy_ms         = str2ull(procfile_lineword(ff, l, 12)); // tot_ticks
+        busy_ms         = str2ull(procfile_lineword(ff, l, 12), NULL); // tot_ticks
 
         // weighted # of milliseconds spent doing I/Os
         // This field is incremented at each I/O start, I/O completion, I/O
@@ -1029,27 +1151,27 @@ int do_proc_diskstats(int update_every, usec_t dt) {
         // (field queued_ios) times the number of milliseconds spent doing I/O since the
         // last update of this field.  This can provide an easy measure of both
         // I/O completion time and the backlog that may be accumulating.
-        backlog_ms      = str2ull(procfile_lineword(ff, l, 13)); // rq_ticks
+        backlog_ms      = str2ull(procfile_lineword(ff, l, 13), NULL); // rq_ticks
 
         if (unlikely(words > 13)) {
             do_dc_stats = 1;
 
             // # of discards completed
             // This is the total number of discards completed successfully.
-            discards       = str2ull(procfile_lineword(ff, l, 14)); // dc_ios
+            discards       = str2ull(procfile_lineword(ff, l, 14), NULL); // dc_ios
 
             // # of discards merged
             // See the description of mreads/mwrites
-            mdiscards      = str2ull(procfile_lineword(ff, l, 15)); // dc_merges
+            mdiscards      = str2ull(procfile_lineword(ff, l, 15), NULL); // dc_merges
 
             // # of sectors discarded
             // This is the total number of sectors discarded successfully.
-            discardsectors = str2ull(procfile_lineword(ff, l, 16)); // dc_sec
+            discardsectors = str2ull(procfile_lineword(ff, l, 16), NULL); // dc_sec
 
             // # of milliseconds spent discarding
             // This is the total number of milliseconds spent by all discards (as
             // measured from __make_request() to end_that_request_last()).
-            discardms      = str2ull(procfile_lineword(ff, l, 17)); // dc_ticks
+            discardms      = str2ull(procfile_lineword(ff, l, 17), NULL); // dc_ticks
         }
 
         if (unlikely(words > 17)) {
@@ -1059,10 +1181,10 @@ int do_proc_diskstats(int update_every, usec_t dt) {
             // These values increment when an flush I/O request completes.
             // Block layer combines flush requests and executes at most one at a time.
             // This counts flush requests executed by disk. Not tracked for partitions.
-            flushes        = str2ull(procfile_lineword(ff, l, 18)); // fl_ios
+            flushes        = str2ull(procfile_lineword(ff, l, 18), NULL); // fl_ios
 
             // total wait time for flush requests
-            flushms        = str2ull(procfile_lineword(ff, l, 19)); // fl_ticks
+            flushms        = str2ull(procfile_lineword(ff, l, 19), NULL); // fl_ticks
         }
 
         // --------------------------------------------------------------------------
@@ -2030,6 +2152,9 @@ int do_proc_diskstats(int update_every, usec_t dt) {
 
             freez(t->disk);
             freez(t->device);
+            freez(t->disk_by_id);
+            freez(t->model);
+            freez(t->serial);
             freez(t->mount_point);
             freez(t->chart_id);
             freez(t);
