@@ -78,7 +78,7 @@ int do_proc_interrupts(int update_every, usec_t dt) {
     size_t words = procfile_linewords(ff, 0);
 
     if(unlikely(!lines)) {
-        error("Cannot read /proc/interrupts, zero lines reported.");
+        collector_error("Cannot read /proc/interrupts, zero lines reported.");
         return 1;
     }
 
@@ -93,7 +93,7 @@ int do_proc_interrupts(int update_every, usec_t dt) {
     }
 
     if(unlikely(!cpus)) {
-        error("PLUGIN: PROC_INTERRUPTS: Cannot find the number of CPUs in /proc/interrupts");
+        collector_error("PLUGIN: PROC_INTERRUPTS: Cannot find the number of CPUs in /proc/interrupts");
         return 1;
     }
 
@@ -120,7 +120,7 @@ int do_proc_interrupts(int update_every, usec_t dt) {
         int c;
         for(c = 0; c < cpus ;c++) {
             if(likely((c + 1) < (int)words))
-                irr->cpu[c].value = str2ull(procfile_lineword(ff, l, (uint32_t)(c + 1)));
+                irr->cpu[c].value = str2ull(procfile_lineword(ff, l, (uint32_t) (c + 1)), NULL);
             else
                 irr->cpu[c].value = 0;
 
