@@ -123,7 +123,7 @@ static struct netdev {
 
     const char *chart_family;
 
-    DICTIONARY *chart_labels;
+    RRDLABELS *chart_labels;
 
     int flipped;
     unsigned long priority;
@@ -348,7 +348,7 @@ static struct netdev_rename {
     const char *container_name;
     const char *ctx_prefix;
 
-    DICTIONARY *chart_labels;
+    RRDLABELS *chart_labels;
 
     int processed;
 
@@ -373,7 +373,7 @@ void netdev_rename_device_add(
     const char *host_device,
     const char *container_device,
     const char *container_name,
-    DICTIONARY *labels,
+    RRDLABELS *labels,
     const char *ctx_prefix)
 {
     netdata_mutex_lock(&netdev_rename_mutex);
@@ -784,13 +784,13 @@ int do_proc_net_dev(int update_every, usec_t dt) {
             snprintfz(buffer, FILENAME_MAX, path_to_sys_devices_virtual_net, d->name);
             if (likely(access(buffer, R_OK) == 0)) {
                 d->virtual = 1;
-                rrdlabels_add(d->chart_labels, "interface_type", "virtual", RRDLABEL_SRC_AUTO|RRDLABEL_FLAG_PERMANENT);
+                rrdlabels_add(d->chart_labels, "interface_type", "virtual", RRDLABEL_SRC_AUTO);
             }
             else {
                 d->virtual = 0;
-                rrdlabels_add(d->chart_labels, "interface_type", "real", RRDLABEL_SRC_AUTO|RRDLABEL_FLAG_PERMANENT);
+                rrdlabels_add(d->chart_labels, "interface_type", "real", RRDLABEL_SRC_AUTO);
             }
-            rrdlabels_add(d->chart_labels, "device", name, RRDLABEL_SRC_AUTO|RRDLABEL_FLAG_PERMANENT);
+            rrdlabels_add(d->chart_labels, "device", name, RRDLABEL_SRC_AUTO);
 
             if(likely(!d->virtual)) {
                 // set the filename to get the interface speed
