@@ -200,7 +200,7 @@ static struct ibport {
 #define GEN_DO_HWCOUNTER_READ(NAME, GRP, DESC, DIR, PORT, HW, ...)                                                     \
     if (HW->file_##NAME) {                                                                                             \
         if (read_single_number_file(HW->file_##NAME, (unsigned long long *)&HW->NAME)) {                               \
-            error("cannot read iface '%s' hwcounter '" #HW "'", PORT->name);                                           \
+            collector_error("cannot read iface '%s' hwcounter '" #HW "'", PORT->name);                                           \
             HW->file_##NAME = NULL;                                                                                    \
         }                                                                                                              \
     }
@@ -327,8 +327,9 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
         enable_only_active = config_get_boolean_ondemand(
             CONFIG_SECTION_PLUGIN_SYS_CLASS_INFINIBAND, "monitor only active ports", CONFIG_BOOLEAN_AUTO);
         disabled_list = simple_pattern_create(
-            config_get(CONFIG_SECTION_PLUGIN_SYS_CLASS_INFINIBAND, "disable by default interfaces matching", ""), NULL,
-            SIMPLE_PATTERN_EXACT);
+                config_get(CONFIG_SECTION_PLUGIN_SYS_CLASS_INFINIBAND, "disable by default interfaces matching", ""),
+                NULL,
+                SIMPLE_PATTERN_EXACT, true);
 
         dt_to_refresh_ports =
             config_get_number(CONFIG_SECTION_PLUGIN_SYS_CLASS_INFINIBAND, "refresh ports state every seconds", 30) *
@@ -468,24 +469,25 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
                 // Sample output: "100 Gb/sec (4X EDR)"
                 snprintfz(buffer, FILENAME_MAX, "%s/%s/%s", ports_dirname, port_dent->d_name, "rate");
                 char buffer_rate[65];
+                p->width = 4;
                 if (read_file(buffer, buffer_rate, 64)) {
-                    error("Unable to read '%s'", buffer);
-                    p->width = 1;
+                    collector_error("Unable to read '%s'", buffer);
                 } else {
                     char *buffer_width = strstr(buffer_rate, "(");
-                    buffer_width++;
-                    // str2ull will stop on first non-decimal value
-                    p->speed = str2ull(buffer_rate);
-                    p->width = str2ull(buffer_width);
+                    if (buffer_width) {
+                        buffer_width++;
+                        // str2ull will stop on first non-decimal value
+                        p->speed = str2ull(buffer_rate, NULL);
+                        p->width = str2ull(buffer_width, NULL);
+                    }
                 }
 
                 if (!p->discovered)
-                    info(
-                        "Infiniband card %s port %s at speed %" PRIu64 " width %" PRIu64 "",
-                        dev_dent->d_name,
-                        port_dent->d_name,
-                        p->speed,
-                        p->width);
+                    collector_info("Infiniband card %s port %s at speed %" PRIu64 " width %" PRIu64 "",
+                                   dev_dent->d_name,
+                                   port_dent->d_name,
+                                   p->speed,
+                                   p->width);
 
                 p->discovered = 1;
             }
@@ -511,7 +513,7 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
 #define GEN_DO_COUNTER_READ(NAME, GRP, DESC, DIR, PORT, ...)                                                           \
     if (PORT->file_##NAME) {                                                                                           \
         if (read_single_number_file(PORT->file_##NAME, (unsigned long long *)&PORT->NAME)) {                           \
-            error("cannot read iface '%s' counter '" #NAME "'", PORT->name);                                           \
+            collector_error("cannot read iface '%s' counter '" #NAME "'", PORT->name);                                           \
             PORT->file_##NAME = NULL;                                                                                  \
         }                                                                                                              \
     }
@@ -541,7 +543,7 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
                 // On this chart, we want to have a KB/s so the dashboard will autoscale it
                 // The reported values are also per-lane, so we must multiply it by the width
                 // x4 lanes multiplier as per Documentation/ABI/stable/sysfs-class-infiniband
-                FOREACH_COUNTER_BYTES(GEN_RRD_DIM_ADD_CUSTOM, port, 4 * 8 * port->width, 1024, RRD_ALGORITHM_INCREMENTAL)
+                FOREACH_COUNTER_BYTES(GEN_RRD_DIM_ADD_CUSTOM, port, port->width * 8, 1000, RRD_ALGORITHM_INCREMENTAL)
 
                 port->stv_speed = rrdsetvar_custom_chart_variable_add_and_acquire(port->st_bytes, "link_speed");
             }
@@ -650,7 +652,7 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
 
                     // Unknown vendor, should not happen
                     else {
-                        error(
+                        collector_error(
                             "Unmanaged vendor for '%s', do_hwerrors should have been set to no. Please report this bug",
                             port->name);
                         port->do_hwerrors = CONFIG_BOOLEAN_NO;
@@ -686,7 +688,7 @@ int do_sys_class_infiniband(int update_every, usec_t dt)
 
                     // Unknown vendor, should not happen
                     else {
-                        error(
+                        collector_error(
                             "Unmanaged vendor for '%s', do_hwpackets should have been set to no. Please report this bug",
                             port->name);
                         port->do_hwpackets = CONFIG_BOOLEAN_NO;
