@@ -18,7 +18,7 @@
 #define ANALYTICS_MAX_DASHBOARD_HITS 255
 
 /* Needed to calculate the space needed for parameters */
-#define ANALYTICS_NO_OF_ITEMS 39
+#define ANALYTICS_NO_OF_ITEMS 40
 
 struct analytics_data {
     char *netdata_config_stream_enabled;
@@ -60,17 +60,22 @@ struct analytics_data {
     char *netdata_config_use_private_registry;
     char *netdata_config_oom_score;
     char *netdata_prebuilt_distro;
+    char *netdata_fail_reason;
 
     size_t data_length;
 
-    uint8_t prometheus_hits;
-    uint8_t shell_hits;
-    uint8_t json_hits;
-    uint8_t dashboard_hits;
+    size_t prometheus_hits;
+    size_t shell_hits;
+    size_t json_hits;
+    size_t dashboard_hits;
+
+    size_t charts_count;
+    size_t metrics_count;
+
+    bool exporting_enabled;
 };
 
-void analytics_get_data(char *name, BUFFER *wb);
-void set_late_global_environment(void);
+void set_late_global_environment(struct rrdhost_system_info *system_info);
 void analytics_free_data(void);
 void set_global_environment(void);
 void send_statistics(const char *action, const char *action_result, const char *action_data);
