@@ -13,6 +13,7 @@ void send_statistics(const char *action, const char *action_result, const char *
 void get_netdata_execution_path(void);
 
 extern char pidfile[];
-extern char exepath[];
+extern char netdata_exe_file[];
+extern char netdata_exe_path[];
 
 #endif /* NETDATA_DAEMON_H */
