@@ -12,7 +12,7 @@ int unit_test_str2ld(void);
 int unit_test_buffer(void);
 int unit_test_static_threads(void);
 int test_sqlite(void);
-int unit_test_bitmap256(void);
+int unit_test_bitmaps(void);
 #ifdef ENABLE_DBENGINE
 int test_dbengine(void);
 void generate_dbengine_dataset(unsigned history_seconds);
