@@ -15,7 +15,6 @@ struct proto_alert_status {
     uint64_t last_submitted_sequence_id;
 };
 
-int aclk_add_alert_event(struct aclk_sync_host_config *wc, struct aclk_database_cmd cmd);
 void aclk_push_alert_event(struct aclk_sync_host_config *wc);
 void aclk_send_alarm_configuration (char *config_hash);
 int aclk_push_alert_config_event(char *node_id, char *config_hash);
@@ -28,8 +27,7 @@ void aclk_push_alarm_checkpoint(RRDHOST *host);
 void aclk_push_alert_snapshot_event(char *node_id);
 void aclk_process_send_alarm_snapshot(char *node_id, char *claim_id, char *snapshot_uuid);
 int get_proto_alert_status(RRDHOST *host, struct proto_alert_status *proto_alert_status);
-int sql_queue_alarm_to_aclk(RRDHOST *host, ALARM_ENTRY *ae, int skip_filter);
+void sql_queue_alarm_to_aclk(RRDHOST *host, ALARM_ENTRY *ae, bool skip_filter);
 void aclk_push_alert_events_for_all_hosts(void);
 
-
 #endif //NETDATA_SQLITE_ACLK_ALERT_H
