@@ -71,7 +71,6 @@ ALARM_ENTRY* health_create_alarm_entry(
     STRING *chart,
     STRING *chart_context,
     STRING *chart_id,
-    STRING *family,
     STRING *classification,
     STRING *component,
     STRING *type,
@@ -84,6 +83,7 @@ ALARM_ENTRY* health_create_alarm_entry(
     RRDCALC_STATUS new_status,
     STRING *source,
     STRING *units,
+    STRING *summary,
     STRING *info,
     int delay,
     HEALTH_ENTRY_FLAGS flags);
