@@ -9,6 +9,7 @@ struct completion {
     uv_mutex_t mutex;
     uv_cond_t cond;
     volatile unsigned completed;
+    volatile unsigned completed_jobs;
 };
 
 void completion_init(struct completion *p);
@@ -19,4 +20,8 @@ void completion_wait_for(struct completion *p);
 
 void completion_mark_complete(struct completion *p);
 
+unsigned completion_wait_for_a_job(struct completion *p, unsigned completed_jobs);
+void completion_mark_complete_a_job(struct completion *p);
+bool completion_is_done(struct completion *p);
+
 #endif /* NETDATA_COMPLETION_H */
