@@ -12,9 +12,9 @@ typedef enum rrdcalc_status {
     RRDCALC_STATUS_UNDEFINED     = -1,
     RRDCALC_STATUS_UNINITIALIZED =  0,
     RRDCALC_STATUS_CLEAR         =  1,
-    RRDCALC_STATUS_RAISED        =  2,
-    RRDCALC_STATUS_WARNING       =  3,
-    RRDCALC_STATUS_CRITICAL      =  4
+    RRDCALC_STATUS_RAISED        =  2, // DO NOT CHANGE THESE NUMBERS
+    RRDCALC_STATUS_WARNING       =  3, // DO NOT CHANGE THESE NUMBERS
+    RRDCALC_STATUS_CRITICAL      =  4, // DO NOT CHANGE THESE NUMBERS
 } RRDCALC_STATUS;
 
 typedef struct eval_variable {
