@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef NETDATA_HEALTH_LIB
 # define NETDATA_HEALTH_LIB 1
 
@@ -9,7 +11,6 @@
 #define HEALTH_CHART_KEY "chart"
 #define HEALTH_HOST_KEY "hosts"
 #define HEALTH_OS_KEY "os"
-#define HEALTH_FAMILIES_KEY "families"
 #define HEALTH_LOOKUP_KEY "lookup"
 #define HEALTH_CALC_KEY "calc"
 
@@ -26,9 +27,6 @@ typedef struct silencer {
     char *charts;
     SIMPLE_PATTERN *charts_pattern;
 
-    char *families;
-    SIMPLE_PATTERN *families_pattern;
-
     struct silencer *next;
 } SILENCER;
 
@@ -44,12 +42,12 @@ typedef struct silencers {
     SILENCER *silencers;
 } SILENCERS;
 
-SILENCERS *silencers;
+extern SILENCERS *silencers;
 
-extern SILENCER *create_silencer(void);
-extern int health_silencers_json_read_callback(JSON_ENTRY *e);
-extern void health_silencers_add(SILENCER *silencer);
-extern SILENCER * health_silencers_addparam(SILENCER *silencer, char *key, char *value);
-extern int health_initialize_global_silencers();
+SILENCER *create_silencer(void);
+int health_silencers_json_read_callback(JSON_ENTRY *e);
+void health_silencers_add(SILENCER *silencer);
+SILENCER * health_silencers_addparam(SILENCER *silencer, char *key, char *value);
+int health_initialize_global_silencers();
 
 #endif
