@@ -8,6 +8,7 @@
 
 // HTTP_CODES 3XX Redirections
 #define HTTP_RESP_MOVED_PERM 301
+#define HTTP_RESP_NOT_MODIFIED 304
 #define HTTP_RESP_REDIR_TEMP 307
 #define HTTP_RESP_REDIR_PERM 308
 #define HTTP_RESP_HTTPS_UPGRADE 399
@@ -22,12 +23,12 @@
 #define HTTP_RESP_CONFLICT 409
 #define HTTP_RESP_PRECOND_FAIL 412
 #define HTTP_RESP_CONTENT_TOO_LONG 413
+#define HTTP_RESP_CLIENT_CLOSED_REQUEST 499 // nginx's enxtension to the standard
 
 // HTTP_CODES 5XX Server Errors
 #define HTTP_RESP_INTERNAL_SERVER_ERROR 500
 #define HTTP_RESP_INTERNAL_SERVER_ERROR_STR "Internal Server Error"
-#define HTTP_RESP_BACKEND_FETCH_FAILED 503  // 503 is right
-#define HTTP_RESP_SERVICE_UNAVAILABLE 503   // 503 is right
+#define HTTP_RESP_SERVICE_UNAVAILABLE 503
 #define HTTP_RESP_GATEWAY_TIMEOUT 504
 #define HTTP_RESP_BACKEND_RESPONSE_INVALID 591
 
