@@ -52,6 +52,7 @@ struct workers_workname {                           // this is what we add to Ju
 static struct workers_globals {
     SPINLOCK spinlock;
     Pvoid_t worknames_JudyHS;
+    size_t memory;
 
 } workers_globals = {                               // workers globals, the base of all worknames
         .spinlock = NETDATA_SPINLOCK_INITIALIZER,   // a lock for the worknames index
@@ -60,6 +61,22 @@ static struct workers_globals {
 
 static __thread struct worker *worker = NULL; // the current thread worker
 
+static inline usec_t worker_now_monotonic_usec(void) {
+#ifdef NETDATA_WITHOUT_WORKERS_LATENCY
+    return 0;
+#else
+    return now_monotonic_usec();
+#endif
+}
+
+size_t workers_allocated_memory(void) {
+    spinlock_lock(&workers_globals.spinlock);
+    size_t memory = workers_globals.memory;
+    spinlock_unlock(&workers_globals.spinlock);
+
+    return memory;
+}
+
 void worker_register(const char *name) {
     if(unlikely(worker)) return;
 
@@ -68,38 +85,40 @@ void worker_register(const char *name) {
     worker->tag = strdupz(netdata_thread_tag());
     worker->workname = strdupz(name);
 
-    usec_t now = now_monotonic_usec();
+    usec_t now = worker_now_monotonic_usec();
     worker->statistics_last_checkpoint = now;
     worker->last_action_timestamp = now;
     worker->last_action = WORKER_IDLE;
 
     size_t name_size = strlen(name) + 1;
-    netdata_spinlock_lock(&workers_globals.spinlock);
+    spinlock_lock(&workers_globals.spinlock);
 
-    Pvoid_t *PValue = JudyHSGet(workers_globals.worknames_JudyHS, (void *)name, name_size);
-    if(!PValue)
-        PValue = JudyHSIns(&workers_globals.worknames_JudyHS, (void *)name, name_size, PJE0);
+    workers_globals.memory += sizeof(struct worker) + strlen(worker->tag) + 1 + strlen(worker->workname) + 1;
+
+    Pvoid_t *PValue = JudyHSIns(&workers_globals.worknames_JudyHS, (void *)name, name_size, PJE0);
 
     struct workers_workname *workname = *PValue;
     if(!workname) {
         workname = mallocz(sizeof(struct workers_workname));
-        workname->spinlock = NETDATA_SPINLOCK_INITIALIZER;
+        spinlock_init(&workname->spinlock);
         workname->base = NULL;
         *PValue = workname;
+
+        workers_globals.memory += sizeof(struct workers_workname) + JUDYHS_INDEX_SIZE_ESTIMATE(name_size);
     }
 
-    netdata_spinlock_lock(&workname->spinlock);
-    DOUBLE_LINKED_LIST_APPEND_UNSAFE(workname->base, worker, prev, next);
-    netdata_spinlock_unlock(&workname->spinlock);
+    spinlock_lock(&workname->spinlock);
+    DOUBLE_LINKED_LIST_APPEND_ITEM_UNSAFE(workname->base, worker, prev, next);
+    spinlock_unlock(&workname->spinlock);
 
-    netdata_spinlock_unlock(&workers_globals.spinlock);
+    spinlock_unlock(&workers_globals.spinlock);
 }
 
 void worker_register_job_custom_metric(size_t job_id, const char *name, const char *units, WORKER_METRIC_TYPE type) {
     if(unlikely(!worker)) return;
 
     if(unlikely(job_id >= WORKER_UTILIZATION_MAX_JOB_TYPES)) {
-        error("WORKER_UTILIZATION: job_id %zu is too big. Max is %zu", job_id, (size_t)(WORKER_UTILIZATION_MAX_JOB_TYPES - 1));
+        netdata_log_error("WORKER_UTILIZATION: job_id %zu is too big. Max is %zu", job_id, (size_t)(WORKER_UTILIZATION_MAX_JOB_TYPES - 1));
         return;
     }
 
@@ -108,7 +127,7 @@ void worker_register_job_custom_metric(size_t job_id, const char *name, const ch
 
     if(worker->per_job_type[job_id].name) {
         if(strcmp(string2str(worker->per_job_type[job_id].name), name) != 0 || worker->per_job_type[job_id].type != type || strcmp(string2str(worker->per_job_type[job_id].units), units) != 0)
-            error("WORKER_UTILIZATION: duplicate job registration: worker '%s' job id %zu is '%s', ignoring the later '%s'", worker->workname, job_id, string2str(worker->per_job_type[job_id].name), name);
+            netdata_log_error("WORKER_UTILIZATION: duplicate job registration: worker '%s' job id %zu is '%s', ignoring the later '%s'", worker->workname, job_id, string2str(worker->per_job_type[job_id].name), name);
         return;
     }
 
@@ -125,20 +144,22 @@ void worker_unregister(void) {
     if(unlikely(!worker)) return;
 
     size_t workname_size = strlen(worker->workname) + 1;
-    netdata_spinlock_lock(&workers_globals.spinlock);
+    spinlock_lock(&workers_globals.spinlock);
     Pvoid_t *PValue = JudyHSGet(workers_globals.worknames_JudyHS, (void *)worker->workname, workname_size);
     if(PValue) {
         struct workers_workname *workname = *PValue;
-        netdata_spinlock_lock(&workname->spinlock);
-        DOUBLE_LINKED_LIST_REMOVE_UNSAFE(workname->base, worker, prev, next);
-        netdata_spinlock_unlock(&workname->spinlock);
+        spinlock_lock(&workname->spinlock);
+        DOUBLE_LINKED_LIST_REMOVE_ITEM_UNSAFE(workname->base, worker, prev, next);
+        spinlock_unlock(&workname->spinlock);
 
         if(!workname->base) {
             JudyHSDel(&workers_globals.worknames_JudyHS, (void *) worker->workname, workname_size, PJE0);
             freez(workname);
+            workers_globals.memory -= sizeof(struct workers_workname) + JUDYHS_INDEX_SIZE_ESTIMATE(workname_size);
         }
     }
-    netdata_spinlock_unlock(&workers_globals.spinlock);
+    workers_globals.memory -= sizeof(struct worker) + strlen(worker->tag) + 1 + strlen(worker->workname) + 1;
+    spinlock_unlock(&workers_globals.spinlock);
 
     for(int i  = 0; i < WORKER_UTILIZATION_MAX_JOB_TYPES ;i++) {
         string_freez(worker->per_job_type[i].name);
@@ -168,14 +189,14 @@ static inline void worker_is_idle_with_time(usec_t now) {
 void worker_is_idle(void) {
     if(unlikely(!worker || worker->last_action != WORKER_BUSY)) return;
 
-    worker_is_idle_with_time(now_monotonic_usec());
+    worker_is_idle_with_time(worker_now_monotonic_usec());
 }
 
 void worker_is_busy(size_t job_id) {
     if(unlikely(!worker || job_id >= WORKER_UTILIZATION_MAX_JOB_TYPES))
         return;
 
-    usec_t now = now_monotonic_usec();
+    usec_t now = worker_now_monotonic_usec();
 
     if(worker->last_action == WORKER_BUSY)
         worker_is_idle_with_time(now);
@@ -226,7 +247,7 @@ void workers_foreach(const char *name, void (*callback)(
                                                , NETDATA_DOUBLE *job_custom_values
                                                )
                                                , void *data) {
-    netdata_spinlock_lock(&workers_globals.spinlock);
+    spinlock_lock(&workers_globals.spinlock);
     usec_t busy_time, delta;
     size_t i, jobs_started, jobs_running;
 
@@ -235,19 +256,19 @@ void workers_foreach(const char *name, void (*callback)(
     Pvoid_t *PValue = JudyHSGet(workers_globals.worknames_JudyHS, (void *)name, workname_size);
     if(PValue) {
         workname = *PValue;
-        netdata_spinlock_lock(&workname->spinlock);
+        spinlock_lock(&workname->spinlock);
     }
     else
         workname = NULL;
 
-    netdata_spinlock_unlock(&workers_globals.spinlock);
+    spinlock_unlock(&workers_globals.spinlock);
 
     if(!workname)
         return;
 
     struct worker *p;
     DOUBLE_LINKED_LIST_FOREACH_FORWARD(workname->base, p, prev, next) {
-        usec_t now = now_monotonic_usec();
+        usec_t now = worker_now_monotonic_usec();
 
         // find per job type statistics
         STRING *per_job_type_name[WORKER_UTILIZATION_MAX_JOB_TYPES];
@@ -358,5 +379,5 @@ void workers_foreach(const char *name, void (*callback)(
                  );
     }
 
-    netdata_spinlock_unlock(&workname->spinlock);
+    spinlock_unlock(&workname->spinlock);
 }
