@@ -8,30 +8,32 @@ NON_INTERACTIVE=0
 DONT_WAIT=0
 
 declare -a package_tree=(
-  gcc
-  gcc-c++
-  make
   autoconf
   autoconf-archive
   autogen
   automake
-  libatomic
-  libtool
-  pkgconfig
   cmake
+  curl
+  elfutils-libelf-devel
+  gcc
+  gcc-c++
+  git
+  gzip
+  json-c-devel
+  libatomic
+  libmnl-devel
+  libtool
+  libuuid-devel
+  libuv-devel
+  libyaml-devel
+  lz4-devel
+  make
+  openssl-devel
+  pkgconfig
+  python3
+  systemd-devel
   tar
   zlib-devel
-  libuuid-devel
-  libmnl-devel
-  json-c-devel
-  libuv-devel
-  lz4-devel
-  openssl-devel
-  python3
-  elfutils-libelf-devel
-  git
-  curl
-  gzip
 )
 
 prompt() {
