@@ -158,7 +158,7 @@ create_tmp_directory() {
     fi
   fi
 
-  mktemp -d -t netdata-kickstart-XXXXXXXXXX
+  mktemp -d -t netdata-uninstaller-XXXXXXXXXX
 }
 
 tmpdir="$(create_tmp_directory)"
@@ -239,15 +239,18 @@ if [ -x "$(command -v apt-get)" ] && [ "${INSTALL_TYPE}" = "binpkg-deb" ]; then
   if dpkg -s netdata > /dev/null; then
     echo "Found netdata native installation"
     if user_input "Do you want to remove netdata? "; then
+      # shellcheck disable=SC2086
       apt-get remove netdata ${FLAG}
     fi
     if dpkg -s netdata-repo-edge > /dev/null; then
       if user_input "Do you want to remove netdata-repo-edge? "; then
+        # shellcheck disable=SC2086
         apt-get remove netdata-repo-edge ${FLAG}
       fi
     fi
     if dpkg -s netdata-repo > /dev/null; then
       if user_input "Do you want to remove netdata-repo? "; then
+        # shellcheck disable=SC2086
         apt-get remove netdata-repo ${FLAG}
       fi
     fi
@@ -257,15 +260,18 @@ elif [ -x "$(command -v dnf)" ] && [ "${INSTALL_TYPE}" = "binpkg-rpm" ]; then
   if rpm -q netdata > /dev/null; then
     echo "Found netdata native installation."
     if user_input "Do you want to remove netdata? "; then
+      # shellcheck disable=SC2086
       dnf remove netdata ${FLAG}
     fi
     if rpm -q netdata-repo-edge > /dev/null; then
       if user_input "Do you want to remove netdata-repo-edge? "; then
+        # shellcheck disable=SC2086
         dnf remove netdata-repo-edge ${FLAG}
       fi
     fi
     if rpm -q netdata-repo > /dev/null; then
       if user_input "Do you want to remove netdata-repo? "; then
+        # shellcheck disable=SC2086
         dnf remove netdata-repo ${FLAG}
       fi
     fi
@@ -275,15 +281,18 @@ elif [ -x "$(command -v yum)" ] && [ "${INSTALL_TYPE}" = "binpkg-rpm" ]; then
   if rpm -q netdata > /dev/null; then
     echo "Found netdata native installation."
     if user_input "Do you want to remove netdata? "; then
+      # shellcheck disable=SC2086
       yum remove netdata ${FLAG}
     fi
     if rpm -q netdata-repo-edge > /dev/null; then
       if user_input "Do you want to remove netdata-repo-edge? "; then
+        # shellcheck disable=SC2086
         yum remove netdata-repo-edge ${FLAG}
       fi
     fi
     if rpm -q netdata-repo > /dev/null; then
       if user_input "Do you want to remove netdata-repo? "; then
+        # shellcheck disable=SC2086
         yum remove netdata-repo ${FLAG}
       fi
     fi
@@ -296,15 +305,18 @@ elif [ -x "$(command -v zypper)" ] && [ "${INSTALL_TYPE}" = "binpkg-rpm" ]; then
   if zypper search -i netdata > /dev/null; then
     echo "Found netdata native installation."
     if user_input "Do you want to remove netdata? "; then
+      # shellcheck disable=SC2086
       zypper ${FLAG} remove netdata
     fi
     if zypper search -i netdata-repo-edge > /dev/null; then
       if user_input "Do you want to remove netdata-repo-edge? "; then
+        # shellcheck disable=SC2086
         zypper ${FLAG} remove netdata-repo-edge
       fi
     fi
     if zypper search -i netdata-repo > /dev/null; then
       if user_input "Do you want to remove netdata-repo? "; then
+        # shellcheck disable=SC2086
         zypper ${FLAG} remove netdata-repo
       fi
     fi
@@ -426,7 +438,7 @@ portable_del_group() {
 
   # Linux
   if command -v groupdel 1> /dev/null 2>&1; then
-    if grep -q "${groupname}" /etc/group; then
+    if get_group "${groupname}" > /dev/null 2>&1; then
       run groupdel "${groupname}" && return 0
     else
       info "Group ${groupname} already removed in a previous step."
@@ -713,25 +725,32 @@ rm_file /usr/lib/systemd/system/netdata-updater.service
 rm_file /etc/systemd/system/netdata-updater.timer
 rm_file /lib/systemd/system/netdata-updater.timer
 rm_file /usr/lib/systemd/system/netdata-updater.timer
+rm_file /usr/lib/systemd/system-preset/50-netdata.preset
+rm_file /lib/systemd/system-preset/50-netdata.preset
 rm_file /etc/init.d/netdata
 rm_file /etc/periodic/daily/netdata-updater
 rm_file /etc/cron.daily/netdata-updater
 rm_file /etc/cron.d/netdata-updater
 
 
-if [ -n "${NETDATA_PREFIX}" ] && [ -d "${NETDATA_PREFIX}" ]; then
+if [ -n "${NETDATA_PREFIX}" ] && [ -d "${NETDATA_PREFIX}" ] && [ "netdata" = "$(basename "$NETDATA_PREFIX")" ] ; then
   rm_dir "${NETDATA_PREFIX}"
 else
-  rm_file "/usr/sbin/netdata"
-  rm_file "/usr/sbin/netdatacli"
+  rm_file "${NETDATA_PREFIX}/usr/sbin/netdata"
+  rm_file "${NETDATA_PREFIX}/usr/sbin/netdatacli"
   rm_file "/tmp/netdata-ipc"
-  rm_file "/usr/sbin/netdata-claim.sh"
-  rm_dir "/usr/share/netdata"
-  rm_dir "/usr/libexec/netdata"
-  rm_dir "/var/lib/netdata"
-  rm_dir "/var/cache/netdata"
-  rm_dir "/var/log/netdata"
-  rm_dir "/etc/netdata"
+  rm_file "/tmp/netdata-service-cmds"
+  rm_file "${NETDATA_PREFIX}/usr/sbin/netdata-claim.sh"
+  rm_dir "${NETDATA_PREFIX}/usr/share/netdata"
+  rm_dir "${NETDATA_PREFIX}/usr/libexec/netdata"
+  rm_dir "${NETDATA_PREFIX}/var/lib/netdata"
+  rm_dir "${NETDATA_PREFIX}/var/cache/netdata"
+  rm_dir "${NETDATA_PREFIX}/var/log/netdata"
+  rm_dir "${NETDATA_PREFIX}/etc/netdata"
+fi
+
+if [ -n "${tmpdir}" ]; then
+  run rm -rf "${tmpdir}" || true
 fi
 
 FILE_REMOVAL_STATUS=1
