@@ -30,7 +30,8 @@ set -euo pipefail
 
 fetch() {
   local dir="${1}" url="${2}" sha256="${3}" key="${4}"
-  local tar="${dir}.tar.gz"
+  local tar
+  tar="$(basename "${2}")"
   local cache="${NETDATA_SOURCE_PATH}/artifacts/cache/${BUILDARCH}/${key}"
 
   if [ -d "${NETDATA_MAKESELF_PATH}/tmp/${dir}" ]; then
@@ -58,10 +59,10 @@ fetch() {
         echo >&2 "expected: ${sha256}, got $(sha256sum "${NETDATA_MAKESELF_PATH}/tmp/${tar}")"
         exit 1
     fi
-    set -e
 
+    set -e
     cd "${NETDATA_MAKESELF_PATH}/tmp"
-    run tar -zxpf "${tar}"
+    run tar -axpf "${tar}"
     cd -
 
     CACHE_HIT=0
