@@ -28,12 +28,6 @@ run cp \
   packaging/makeself/post-installer.sh \
   packaging/makeself/install-or-update.sh \
   packaging/installer/functions.sh \
-  configs.signatures \
-  system/netdata-init-d \
-  system/netdata-lsb \
-  system/netdata-openrc \
-  system/netdata.logrotate \
-  system/netdata.service \
   "${NETDATA_INSTALL_PATH}/system/"
 
 # -----------------------------------------------------------------------------
@@ -52,6 +46,12 @@ exec "${NETDATA_INSTALL_PATH}/bin/srv/netdata" "\${@}"
 EOF
 run chmod 755 "${NETDATA_INSTALL_PATH}/bin/netdata"
 
+# -----------------------------------------------------------------------------
+# the claiming script must be in the same directory as the netdata binary for web-based claiming to work
+
+run ln -s "${NETDATA_INSTALL_PATH}/bin/netdata-claim.sh" \
+  "${NETDATA_INSTALL_PATH}/bin/srv/netdata-claim.sh" || exit 1
+
 # -----------------------------------------------------------------------------
 # copy the SSL/TLS configuration and certificates from the build system
 
@@ -65,6 +65,14 @@ run rm "${NETDATA_INSTALL_PATH}/sbin" \
   "${NETDATA_INSTALL_PATH}/usr/sbin" \
   "${NETDATA_INSTALL_PATH}/usr/local"
 
+# -----------------------------------------------------------------------------
+# ensure required directories actually exist
+
+for dir in var/lib/netdata var/cache/netdata var/log/netdata ; do
+    run mkdir -p "${NETDATA_INSTALL_PATH}/${dir}"
+    run touch "${NETDATA_INSTALL_PATH}/${dir}/.keep"
+done
+
 # -----------------------------------------------------------------------------
 # create the makeself archive
 
