@@ -5,8 +5,7 @@
 
 #include "rrd2json.h"
 
-void charts2json(RRDHOST *host, BUFFER *wb, int skip_volatile, int show_archived);
-void chartcollectors2json(RRDHOST *host, BUFFER *wb);
+void charts2json(RRDHOST *host, BUFFER *wb, int skip_volatile);
 const char* get_release_channel();
 
 #endif //NETDATA_API_FORMATTER_CHARTS2JSON_H
