@@ -25,6 +25,13 @@ NETDATA.unitsConversion = {
             'gigabits/s': 1000000,
             'terabits/s': 1000000000
         },
+        'bytes/s': {
+            'bytes/s': 1,
+            'kilobytes/s': 1024,
+            'megabytes/s': 1024 * 1024,
+            'gigabytes/s': 1024 * 1024 * 1024,
+            'terabytes/s': 1024 * 1024 * 1024 * 1024
+        },
         'kilobytes/s': {
             'bytes/s': 1 / 1024,
             'kilobytes/s': 1,
@@ -32,6 +39,13 @@ NETDATA.unitsConversion = {
             'gigabytes/s': 1024 * 1024,
             'terabytes/s': 1024 * 1024 * 1024
         },
+        'B/s': {
+            'B/s': 1,
+            'KiB/s': 1024,
+            'MiB/s': 1024 * 1024,
+            'GiB/s': 1024 * 1024 * 1024,
+            'TiB/s': 1024 * 1024 * 1024 * 1024
+        },
         'KB/s': {
             'B/s': 1 / 1024,
             'KB/s': 1,
